@@ -10,9 +10,12 @@ def test_log_warn():
     log_init_config("/tmp", "spider")
     log_warn("test log warn")
 
+def error_callback(message):
+    print("xxxx:" + message)
 
 def test_log_error():
-    log_init_config("/tmp", "spider")
+    set_error_callback(error_callback)
+    log_init_config("/tmp", "spider1", split_error_log=True)
     log_error("test log error")
 
 
